'===============================================================================
' Editor.bas
' Very simple text editor
' Created on January 15, 2023
' Last changes on October 12, 2023
'===============================================================================

#Include "WinLib.bi"
#Include "FileDialogs.bi"

Dim Shared As HMENU hMenu, hFile, hHelp
Dim Shared As HWND MainWindow, Edit_txt
Dim Shared As ZString*MAX_PATH file


Sub FileOpen()
	'Open file
	
	Dim As String text
		
	TextBox_SetText(Edit_txt, "")
  OpenFileDilog(MainWindow,, @file)
  If file <> "" Then
		Open file For Binary As #1
		text = Space(LOF(1))
		Get #1,, text
		Close #1
		TextBox_SetText(Edit_txt, text)
		SetWindowText(MainWindow, file)
	End If
	
End Sub


Sub FileSave()
	'Save file
	
	Dim As String text
	
	SaveFileDilog(MainWindow,, @file)
	If file <> "" Then
		TextBox_GetText(Edit_txt)
		Open file For Binary As #1
		Put #1,, TextBox_GetText(Edit_txt)
		Close #1
		SetWindowText(MainWindow, file)
	End If
		
End Sub


Function WndProc(ByVal hWnd As HWND, ByVal Msg As UINT, ByVal wParam As WPARAM, ByVal lParam As LPARAM ) As LRESULT
      
  Dim As HFONT Font
  Dim As Long x0, y0, x1, y1
    
	Function = 0
	
	Select Case Msg
	
		Case WM_CREATE            

			'Menu:
			hMenu = CreateMenu()
			hFile = CreateMenu()
			hHelp = CreateMenu()
			MenuTitle(hMenu, hFile, "File")
			MenuTitle(hMenu, hHelp, "Help")
			MenuItem(hFile, 1, "New")
			MenuItem(hFile, 2, "Open")
			MenuItem(hFile, 3, "Save")
			MenuItem(hFile, 4, "Quit")
			MenuItem(hHelp, 5, "?")
			SetMenu(hwnd, hMenu)
			
			'Editor with Font "Courier New":
			Edit_txt = TextEditor_New(10, 10, 630, 400, "",, hWnd)
			Font = Control_Createfont("Courier New", 16, 8)
      Control_Setfont(Edit_txt, Font)
						
		Case WM_COMMAND
		
			Select Case LoWord(wParam)
				'Menu:
				Case 1
					TextBox_SetText(Edit_txt, "")
					SetWindowText(hWnd, "Simple Editor")
				Case 2
					FileOpen()
				Case 3
					FileSave()
				Case 4
					SendMessage(hWnd, WM_CLOSE, 0, 0)
				Case 5
					MessageBox(hWnd, _
						"A small texteditor" & Chr(10) & _
						"written in FreeBASIC" & Chr(10) & _
						"using the Windows API", "Info", MB_ICONINFORMATION)
			End Select
		
		Case WM_SIZE
			'Adapt editbox to window size:
			Window_GetSize(hWnd, x0, y0, x1, y1)
			Control_Resize(Edit_txt, x0 + 10, y0 + 10, x1 - 20, y1 - 50)
			
		Case WM_DESTROY
			Control_Deletefont(Font)
			PostQuitMessage(0)
			Exit Function
			
	End Select
	
	Return DefWindowProc(hWnd, Msg, wParam, lParam)    
    
End Function


RegisterWindowClass("WindowClass", @WndProc)
MainWindow = Window_New("WindowClass", CW_USEDEFAULT, CW_USEDEFAULT, 650, 450, "Simple Editor")
RunMessageLoop()

End


