'===============================================================================
' FileDialogs.bi
' Created on May 23, 2021
' Latest changes on January 16, 2023
'===============================================================================

#Include Once "windows.bi"
#Include Once "win\commdlg.bi"


'-------------------------------------------------------------------------------
' File dialog boxes
' by MichaelW Aug 22, 2012
' https://www.freebasic.net/forum/viewtopic.php?f=3&t=20302&p=178095&hilit=GUI#p178095
' (modified)
'-------------------------------------------------------------------------------

' Note that for the following two functions the string pointed to
' by pszFile must be large enough to receive the drive designator,
' path, file name, and extension of the specified file, and that
' the size must be specified in nMaxFile. The size is typically
' specified as the MAX_PATH constant.


Function OpenFileDilog(ByVal hwndOwner as HWND,_
	ByVal filter As String = "Text Files (*.txt)" & Chr(0) & "*.txt" & Chr(0) _
		& "All Files (*.*)" & Chr(0) + "*.*" & Chr(0, 0), _
	ByVal pszFile as zstring ptr, ByVal nMaxFile as integer = MAX_PATH) As Integer
' This function sets up and opens the Open dialog box and returns
' whatever the GetOpenFileName function returned. The return value
' will be zero if the user canceled the dialog or an error occurred,
' or non-zero if the user specified a file and clicked OK, in which
' case the string pointed to by pszFile will contain the full path
' and filename of the file specified by the user.

	Dim As OPENFILENAME OFN
		
	OFN.lStructSize = sizeof(OPENFILENAME)
	OFN.hWndOwner = hwndOwner
	'OFN.lpstrFilter = StrPtr(!"All Files (*.*)\0*.*\0\0")
	'filter = "All Files (*.*)" & Chr(0) +"*.*" & Chr(0, 0)
	OFN.lpstrFilter = StrPtr(filter)
	OFN.lpstrFile = pszFile
	OFN.nMaxFile = nMaxFile
	OFN.Flags = OFN_FILEMUSTEXIST or OFN_LONGNAMES Or OFN_HIDEREADONLY

	Return GetOpenFileName(@OFN)

End Function


Function SaveFileDilog(Byval hwndOwner as HWND, _
	ByVal filter As String = "Text Files (*.txt)" & Chr(0) & "*.txt" & Chr(0) _
		& "All Files (*.*)" & Chr(0) + "*.*" & Chr(0, 0), _
	Byval pszFile as zstring ptr, _
  Byval nMaxFile as integer = MAX_PATH) As Integer
' This function sets up and opens the Save As dialog box and returns
' whatever the GetSaveFileName function returned. The return value
' will be zero if the user canceled the dialog or an error occurred,
' or non-zero if the user specified a file name and clicked OK, in
' which case the string pointed to by pszFile will contain the full
' path and filename specified by the user.

	Dim As OPENFILENAME OFN

	OFN.lStructSize = sizeof(OPENFILENAME)
	OFN.hWndOwner = hwndOwner
	OFN.lpstrFilter = StrPtr(filter)
	OFN.lpstrFile = pszFile
	OFN.nMaxFile = nMaxFile
	OFN.Flags = OFN_LONGNAMES

	Return GetSaveFileName(@OFN)

End Function

/'------------------------------------------------------------------------------
	Simple demo of the GetOpenFileName and GetSaveFileName common dialog boxes,
	build as a console app. These would normally be called from the main window
	of a UI app, and the handle of the window would be passed in the hwndOwner
	parameter.
	------------------------------------------------------------------------------
	
	Dim As ZString * MAX_PATH file

	Print OpenFileDilog(0,, @file)
	Print file

	Print SaveFileDilog(0,, @file)
	Print file

Sleep
'/


